from .History_HistoryStep import History_HistoryStep


class History_Remove(History_HistoryStep):

	pass


